import pandas as pd
import numpy as np
from sklearn.model_selection import train_test_split
from sklearn.ensemble import RandomForestClassifier
from sklearn.metrics import accuracy_score
import plotly.express as px
import dash
from dash import html, dcc

# Test Data Generation
np.random.seed(42)
data_size = 1000
features = pd.DataFrame({
    'Feature1': np.random.rand(data_size),
    'Feature2': np.random.rand(data_size),
    'Label': np.random.choice([0, 1], size=data_size)
})

# Splitting data into training and testing
X_train, X_test, y_train, y_test = train_test_split(features[['Feature1', 'Feature2']], features['Label'], test_size=0.2, random_state=42)

# Model Training
model = RandomForestClassifier(random_state=42)
model.fit(X_train, y_train)

# Predictions on the test set
y_pred = model.predict(X_test)

# Model Evaluation
accuracy = accuracy_score(y_test, y_pred)

# Creating plot
fig = px.scatter(features, x='Feature1', y='Feature2', color='Label', title='Scatter Plot of Features')

# Creating Dash Interface
app = dash.Dash(__name__)
app.layout = html.Div(children=[
    html.H1(children='CyberEduPlatform - Basic Version'),

    html.Div(children=[
        html.H2('Test Data Generation'),
        html.P(f'Data generated randomly. Dataset size: {data_size}'),
    ]),

    html.Div(children=[
        html.H2('Model Training'),
        html.P(f'Model used: Random Forest Classifier'),
        html.P(f'Model accuracy: {accuracy:.2%}'),
    ]),

    html.Div(children=[
        html.H2('Data Visualization'),
        dcc.Graph(figure=fig),
    ]),
])

if __name__ == '__main__':
    app.run_server(debug=True)
