import pandas as pd
import plotly.express as px
import dash
from dash import html, dcc

# Load data from the CSV file
file_path = "C:/Users/ciberseguridad-plataforma/PeerJ/data.csv"
df = pd.read_csv(file_path)

# Complex data analysis
# You can add more specific analysis for each variable here

# Create specific charts
attack_pie_fig = px.pie(df, names='Attack_Type', title='Distribution of Attack Types')

protocol_counts = df['Protocol'].value_counts()
protocol_bar_fig = px.bar(protocol_counts, x=protocol_counts.index, y=protocol_counts.values, labels={'x': 'Protocol', 'y': 'Count'}, title='Distribution of Protocols')

# Dash interface creation
app = dash.Dash(__name__)
app.layout = html.Div(children=[
    html.H1(children='Analysis of Cybersecurity Data'),

    html.Div(children=[
        html.H2('Distribution of Attack Types'),
        dcc.Graph(figure=attack_pie_fig),
    ]),

    html.Div(children=[
        html.H2('Distribution of Protocols'),
        dcc.Graph(figure=protocol_bar_fig),
    ]),
])

if __name__ == '__main__':
    app.run_server(debug=True)
